@@ -954,6 +954,7 @@ def agentmake(
                     prefill=prefill_content,
                     stop=stop,
                     stream=stream,
+                    api_key=api_key,
                     api_endpoint=api_endpoint,
                     **kwargs
                 )
@@ -1095,7 +1096,6 @@ def agentmake(
         #print(messages_copy)
         return messages_copy
     except KeyboardInterrupt:
-        # print("Stopped by user!")
         return []
 
 def refine_system_instruction(
@@ -1127,7 +1127,7 @@ def refine_system_instruction(
     if system_instruction in ("auto", "reasoning") and user_prompt:
         if print_on_terminal:
             print(">>> Generating system instruction ...\n")
-        system_instruction = agentmake(
+        system_instruction_output = agentmake(
             user_prompt,
             system="create_reasoning_agent" if system_instruction == "reasoning" else "create_agent",
             instruction=os.path.join("system", "auto"),
@@ -1147,7 +1147,10 @@ def refine_system_instruction(
             print_on_terminal=print_on_terminal,
             word_wrap=word_wrap,
             **kwargs,
-        )[-1].get("content", "")
+        )
+        if not system_instruction_output:
+            return []
+        system_instruction = system_instruction_output[-1].get("content", "")
         if agent := re.search("""```agent(.+?)```""", system_instruction, re.DOTALL):
             system_instruction = agent.group(1).strip()
         try:
@@ -1173,7 +1176,7 @@ def refine_system_instruction(
             # generate new role
             if print_on_terminal:
                 print(">>> Generating system instruction ...\n")
-            system_instruction = agentmake(
+            system_instruction_output = agentmake(
                 role,
                 instruction=os.path.join("system", "role"),
                 backend=backend,
@@ -1192,7 +1195,10 @@ def refine_system_instruction(
                 print_on_terminal=print_on_terminal,
                 word_wrap=word_wrap,
                 **kwargs,
-            )[-1].get("content", "")
+            )
+            if not system_instruction_output:
+                return []
+            system_instruction = system_instruction_output[-1].get("content", "")
         try:
             user_systems_file = saveUserSystemMessage(system_instruction, subfolder="roles", filename=role)
             if print_on_terminal:
@@ -1692,4 +1698,5 @@ def getFabricPatternSystem(pattern, instruction=False):
 # Suppress ResourceWarnings for Ollama connections
 # This is a workaround for the issue with Ollama connections not being closed properly
 import warnings
-warnings.filterwarnings("ignore", category=ResourceWarning, message=r"unclosed <socket.socket.*11434\)>")
\ No newline at end of file
+warnings.filterwarnings("ignore", category=ResourceWarning, message=r"unclosed <socket.socket.*11434\)>")
+warnings.filterwarnings("ignore", category=ResourceWarning, message=r"unclosed <ssl.SSLSocket ")
\ No newline at end of file
